@@ -5,6 +5,8 @@ module HIndent.Ast.Declaration.Data.Deriving.Strategy
   ) where
 
 import HIndent.Ast.NodeComments
+import HIndent.Ast.Type (Type, mkTypeFromHsSigType)
+import HIndent.Ast.WithComments (WithComments, flattenComments, fromGenLocated)
 import qualified HIndent.GhcLibParserWrapper.GHC.Hs as GHC
 import {-# SOURCE #-} HIndent.Pretty
 import HIndent.Pretty.Combinators
@@ -14,7 +16,7 @@ data DerivingStrategy
   = Stock
   | Anyclass
   | Newtype
-  | Via (GHC.LHsSigType GHC.GhcPs)
+  | Via (WithComments Type)
 
 instance CommentExtraction DerivingStrategy where
   nodeComments Stock {} = NodeComments [] [] []
@@ -32,7 +34,8 @@ mkDerivingStrategy :: GHC.DerivStrategy GHC.GhcPs -> DerivingStrategy
 mkDerivingStrategy GHC.StockStrategy {} = Stock
 mkDerivingStrategy GHC.AnyclassStrategy {} = Anyclass
 mkDerivingStrategy GHC.NewtypeStrategy {} = Newtype
-mkDerivingStrategy (GHC.ViaStrategy (GHC.XViaStrategyPs _ x)) = Via x
+mkDerivingStrategy (GHC.ViaStrategy (GHC.XViaStrategyPs _ x)) =
+  Via $ flattenComments $ mkTypeFromHsSigType <$> fromGenLocated x
 
 isViaStrategy :: DerivingStrategy -> Bool
 isViaStrategy Via {} = True
