@@ -5,15 +5,18 @@ module HIndent.Ast.Declaration.Data.Record.Field
   , mkRecordField
   ) where
 
+import HIndent.Ast.Name.RecordField (FieldName, mkFieldNameFromFieldOcc)
 import HIndent.Ast.NodeComments
+import {-# SOURCE #-} HIndent.Ast.Type
+import HIndent.Ast.WithComments
 import qualified HIndent.GhcLibParserWrapper.GHC.Hs as GHC
 import {-# SOURCE #-} HIndent.Pretty
 import HIndent.Pretty.Combinators
 import HIndent.Pretty.NodeComments
 
 data RecordField = RecordField
-  { names :: [GHC.LFieldOcc GHC.GhcPs]
-  , ty :: GHC.LBangType GHC.GhcPs
+  { names :: [WithComments FieldName]
+  , ty :: WithComments Type
   }
 
 instance CommentExtraction RecordField where
@@ -26,5 +29,5 @@ instance Pretty RecordField where
 mkRecordField :: GHC.ConDeclField GHC.GhcPs -> RecordField
 mkRecordField GHC.ConDeclField {..} = RecordField {..}
   where
-    names = cd_fld_names
-    ty = cd_fld_type
+    names = fmap mkFieldNameFromFieldOcc . fromGenLocated <$> cd_fld_names
+    ty = mkType <$> fromGenLocated cd_fld_type
