@@ -1,3 +1,5 @@
+{-# LANGUAGE CPP #-}
+
 module HIndent.Ast.Declaration.Default
   ( DefaultDeclaration
   , mkDefaultDeclaration
@@ -5,12 +7,14 @@ module HIndent.Ast.Declaration.Default
 
 import qualified GHC.Hs as GHC
 import HIndent.Ast.NodeComments
+import HIndent.Ast.Type
+import HIndent.Ast.WithComments
 import {-# SOURCE #-} HIndent.Pretty
 import HIndent.Pretty.Combinators
 import HIndent.Pretty.NodeComments
 
 newtype DefaultDeclaration =
-  DefaultDeclaration [GHC.LHsType GHC.GhcPs]
+  DefaultDeclaration [WithComments Type]
 
 instance CommentExtraction DefaultDeclaration where
   nodeComments DefaultDeclaration {} = NodeComments [] [] []
@@ -20,4 +24,10 @@ instance Pretty DefaultDeclaration where
     spaced [string "default", hTuple $ fmap pretty xs]
 
 mkDefaultDeclaration :: GHC.DefaultDecl GHC.GhcPs -> DefaultDeclaration
-mkDefaultDeclaration (GHC.DefaultDecl _ xs) = DefaultDeclaration xs
+#if MIN_VERSION_ghc_lib_parser(9, 12, 1)
+mkDefaultDeclaration (GHC.DefaultDecl _ _ xs) =
+  DefaultDeclaration $ fmap (fmap mkType . fromGenLocated) xs
+#else
+mkDefaultDeclaration (GHC.DefaultDecl _ xs) =
+  DefaultDeclaration $ fmap (fmap mkType . fromGenLocated) xs
+#endif
