@@ -4,6 +4,7 @@ module HIndent.Ast.Declaration.Family.Type.ResultSignature
   ) where
 
 import HIndent.Ast.NodeComments
+import HIndent.Ast.Type
 import HIndent.Ast.Type.Variable
 import HIndent.Ast.WithComments
 import qualified HIndent.GhcLibParserWrapper.GHC.Hs as GHC
@@ -13,7 +14,7 @@ import HIndent.Pretty.NodeComments
 
 data ResultSignature
   = NoSig
-  | Kind (GHC.LHsKind GHC.GhcPs)
+  | Kind (WithComments Type)
   | TypeVariable (WithComments TypeVariable)
 
 instance CommentExtraction ResultSignature where
@@ -28,7 +29,7 @@ instance Pretty ResultSignature where
 
 mkResultSignature :: GHC.FamilyResultSig GHC.GhcPs -> ResultSignature
 mkResultSignature (GHC.NoSig _) = NoSig
-mkResultSignature (GHC.KindSig _ x) = Kind x
+mkResultSignature (GHC.KindSig _ x) = Kind $ mkType <$> fromGenLocated x
 mkResultSignature (GHC.TyVarSig _ x) = TypeVariable var
   where
     var = mkTypeVariable <$> fromGenLocated x
