@@ -7,6 +7,7 @@ module HIndent.Ast.Declaration.Instance.Family.Type
 
 import HIndent.Ast.Name.Prefix
 import HIndent.Ast.NodeComments
+import HIndent.Ast.Type
 import HIndent.Ast.WithComments
 import qualified HIndent.GhcLibParserWrapper.GHC.Hs as GHC
 import {-# SOURCE #-} HIndent.Pretty
@@ -16,13 +17,13 @@ import HIndent.Pretty.NodeComments
 data TypeFamilyInstance = TypeFamilyInstance
   { name :: WithComments PrefixName
   , types :: GHC.HsFamEqnPats GHC.GhcPs
-  , bind :: GHC.LHsType GHC.GhcPs
+  , bind :: WithComments Type
   }
 #else
 data TypeFamilyInstance = TypeFamilyInstance
   { name :: WithComments PrefixName
   , types :: GHC.HsTyPats GHC.GhcPs
-  , bind :: GHC.LHsType GHC.GhcPs
+  , bind :: WithComments Type
   }
 #endif
 instance CommentExtraction TypeFamilyInstance where
@@ -40,5 +41,5 @@ mkTypeFamilyInstance GHC.TyFamInstD {GHC.tfid_inst = GHC.TyFamInstDecl {GHC.tfid
   where
     name = fromGenLocated $ fmap mkPrefixName feqn_tycon
     types = feqn_pats
-    bind = feqn_rhs
+    bind = mkType <$> fromGenLocated feqn_rhs
 mkTypeFamilyInstance _ = Nothing
