@@ -7,6 +7,7 @@ module HIndent.Ast.Declaration.Rule.Binder
 
 import HIndent.Ast.Name.Prefix
 import HIndent.Ast.NodeComments
+import HIndent.Ast.Type
 import HIndent.Ast.WithComments
 import qualified HIndent.GhcLibParserWrapper.GHC.Hs as GHC
 import {-# SOURCE #-} HIndent.Pretty
@@ -15,7 +16,7 @@ import HIndent.Pretty.NodeComments
 
 data RuleBinder = RuleBinder
   { name :: WithComments PrefixName
-  , signature :: Maybe (WithComments (GHC.HsType GHC.GhcPs))
+  , signature :: Maybe (WithComments Type)
   }
 
 instance CommentExtraction RuleBinder where
@@ -33,5 +34,5 @@ mkRuleBinder (GHC.RuleBndr _ n) = RuleBinder {..}
     name = fromGenLocated $ fmap mkPrefixName n
 mkRuleBinder (GHC.RuleBndrSig _ n GHC.HsPS {..}) = RuleBinder {..}
   where
-    signature = Just $ fromGenLocated hsps_body
+    signature = Just $ fromGenLocated $ fmap mkType hsps_body
     name = fromGenLocated $ fmap mkPrefixName n
