@@ -8,6 +8,7 @@ module HIndent.Ast.Declaration.Signature.StandaloneKind
 import qualified GHC.Hs as GHC
 import HIndent.Ast.Name.Prefix
 import HIndent.Ast.NodeComments
+import HIndent.Ast.Type (Type, mkTypeFromHsSigType)
 import HIndent.Ast.WithComments
 import {-# SOURCE #-} HIndent.Pretty
 import HIndent.Pretty.Combinators
@@ -15,7 +16,7 @@ import HIndent.Pretty.NodeComments
 
 data StandaloneKind = StandaloneKind
   { name :: WithComments PrefixName
-  , kind :: GHC.LHsSigType GHC.GhcPs
+  , kind :: WithComments Type
   }
 
 instance CommentExtraction StandaloneKind where
@@ -26,6 +27,7 @@ instance Pretty StandaloneKind where
     spaced [string "type", pretty name, string "::", pretty kind]
 
 mkStandaloneKind :: GHC.StandaloneKindSig GHC.GhcPs -> StandaloneKind
-mkStandaloneKind (GHC.StandaloneKindSig _ n kind) = StandaloneKind {..}
+mkStandaloneKind (GHC.StandaloneKindSig _ n k) = StandaloneKind {..}
   where
     name = fromGenLocated $ fmap mkPrefixName n
+    kind = flattenComments $ mkTypeFromHsSigType <$> fromGenLocated k
