@@ -5,19 +5,20 @@ module HIndent.Ast.Declaration.Splice
 
 import HIndent.Ast.Expression.Splice
 import HIndent.Ast.NodeComments
+import HIndent.Ast.WithComments
 import qualified HIndent.GhcLibParserWrapper.GHC.Hs as GHC
 import {-# SOURCE #-} HIndent.Pretty
 import HIndent.Pretty.NodeComments
 
 newtype SpliceDeclaration =
-  SpliceDeclaration (GHC.SpliceDecl GHC.GhcPs)
+  SpliceDeclaration (WithComments Splice)
 
 instance CommentExtraction SpliceDeclaration where
   nodeComments SpliceDeclaration {} = NodeComments [] [] []
 
 instance Pretty SpliceDeclaration where
-  pretty' (SpliceDeclaration (GHC.SpliceDecl _ sp _)) =
-    pretty $ fmap mkSplice sp
+  pretty' (SpliceDeclaration splice) = pretty splice
 
 mkSpliceDeclaration :: GHC.SpliceDecl GHC.GhcPs -> SpliceDeclaration
-mkSpliceDeclaration = SpliceDeclaration
+mkSpliceDeclaration (GHC.SpliceDecl _ sp _) =
+  SpliceDeclaration $ mkSplice <$> fromGenLocated sp
