@@ -27,7 +27,9 @@ instance CommentExtraction ModuleDeclaration where
 
 instance Pretty ModuleDeclaration where
   pretty' ModuleDeclaration {..} = do
-    pretty name
+    prettyWith name $ \n -> do
+      string "module "
+      pretty n
     whenJust warning $ \x -> do
       space
       pretty x
@@ -41,6 +43,7 @@ mkModuleDeclaration m =
   case GHC.hsmodName m of
     Nothing -> Nothing
     Just name' -> Just ModuleDeclaration {..}
-      where name = mkModuleName <$> fromGenLocated name'
-            warning = mkModuleWarning m
-            exports = mkExportCollection m
+      where
+        name = mkModuleName <$> fromGenLocated name'
+        warning = mkModuleWarning m
+        exports = mkExportCollection m
