@@ -5,18 +5,19 @@ module HIndent.Ast.Module.Name
 
 import qualified GHC.Unit as GHC
 import HIndent.Ast.NodeComments
-import HIndent.Pretty
+import {-# SOURCE #-} HIndent.Pretty
 import HIndent.Pretty.Combinators
 import HIndent.Pretty.NodeComments
 
 newtype ModuleName =
   ModuleName String
+  deriving (Eq, Ord)
 
 instance CommentExtraction ModuleName where
   nodeComments _ = NodeComments [] [] []
 
 instance Pretty ModuleName where
-  pretty' (ModuleName x) = string "module " >> string x
+  pretty' (ModuleName x) = string x
 
 mkModuleName :: GHC.ModuleName -> ModuleName
 mkModuleName = ModuleName . GHC.moduleNameString
