@@ -3,20 +3,24 @@
 module HIndent.Ast.Name.Infix
   ( InfixName
   , mkInfixName
+  , getInfixName
+  , unlessSpecialOp
   ) where
 
+import Control.Monad
 import Data.Maybe
 import qualified GHC.Types.Name as GHC
 import qualified GHC.Types.Name.Reader as GHC
-import qualified GHC.Unit.Module as GHC
+import HIndent.Ast.Module.Name
 import HIndent.Ast.NodeComments
 import {-# SOURCE #-} HIndent.Pretty
-import HIndent.Pretty.Combinators
+import HIndent.Pretty.Combinators hiding (unlessSpecialOp)
 import HIndent.Pretty.NodeComments
+import HIndent.Printer
 
 data InfixName = InfixName
-  { name :: GHC.OccName
-  , moduleName :: Maybe GHC.ModuleName
+  { name :: String
+  , moduleName :: Maybe ModuleName
   , backtick :: Bool
   }
 
@@ -25,7 +29,7 @@ instance CommentExtraction InfixName where
 
 instance Pretty InfixName where
   pretty' InfixName {..} =
-    wrap $ hDotSep $ catMaybes [pretty <$> moduleName, Just $ pretty name]
+    wrap $ hDotSep $ catMaybes [pretty <$> moduleName, Just $ string name]
     where
       wrap =
         if backtick
@@ -33,13 +37,26 @@ instance Pretty InfixName where
           else id
 
 mkInfixName :: GHC.RdrName -> InfixName
-mkInfixName (GHC.Unqual name) = InfixName name Nothing (backticksNeeded name)
+mkInfixName (GHC.Unqual name) =
+  InfixName (showOutputable name) Nothing (backticksNeeded name)
 mkInfixName (GHC.Qual modName name) =
-  InfixName name (Just modName) (backticksNeeded name)
+  InfixName
+    (showOutputable name)
+    (Just $ mkModuleName modName)
+    (backticksNeeded name)
 mkInfixName (GHC.Orig {}) =
   error "This AST node should not appear in the parser output."
 mkInfixName (GHC.Exact name) =
-  InfixName (GHC.occName name) Nothing (backticksNeeded $ GHC.occName name)
+  InfixName
+    (showOutputable $ GHC.occName name)
+    Nothing
+    (backticksNeeded $ GHC.occName name)
+
+getInfixName :: InfixName -> String
+getInfixName = name
+
+unlessSpecialOp :: InfixName -> Printer () -> Printer ()
+unlessSpecialOp InfixName {..} = unless $ name `elem` ["()", "[]", "->", ":"]
 
 backticksNeeded :: GHC.OccName -> Bool
 backticksNeeded = not . GHC.isSymOcc
