@@ -6,7 +6,6 @@ module HIndent.Pretty.Combinators
   , module HIndent.Pretty.Combinators.Lineup
   , module HIndent.Pretty.Combinators.Op
   , module HIndent.Pretty.Combinators.Outputable
-  , module HIndent.Pretty.Combinators.RhsSeparator
   , module HIndent.Pretty.Combinators.String
   , module HIndent.Pretty.Combinators.Switch
   , module HIndent.Pretty.Combinators.Wrap
@@ -18,7 +17,6 @@ import HIndent.Pretty.Combinators.Indent
 import HIndent.Pretty.Combinators.Lineup
 import HIndent.Pretty.Combinators.Op
 import HIndent.Pretty.Combinators.Outputable
-import HIndent.Pretty.Combinators.RhsSeparator
 import HIndent.Pretty.Combinators.String
 import HIndent.Pretty.Combinators.Switch
 import HIndent.Pretty.Combinators.Wrap
